/**
***  bitmaps.c -- bitmaps for AmyBoard
***
*** ------------------------------------------------------------------------
***  This program is free software; you can redistribute it and/or modify
***  it under the terms of the GNU General Public License as published by
***  the Free Software Foundation; either version 2 of the License, or
***  (at your option) any later version.
***
***  This program is distributed in the hope that it will be useful,
***  but WITHOUT ANY WARRANTY; without even the implied warranty of
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
***  GNU General Public License for more details.
***
***  You should have received a copy of the GNU General Public License
***  along with this program; if not, write to the Free Software
***  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*** ------------------------------------------------------------------------
***
***
***  This file contains just the usual bitmaps of AmyBoard which are usually
***  stored in the bitmaps directory of the source distribution.
***
***  Modifications are:
***
***	- Bitmaps are in a separate source file, thus in a separate
***	  object file. This allows to tell the linker to put them into
***	  chip memory.
***
***	- Bitmaps are word aligned, that means every row contains
***	  multiples of 16 pixels. (This is the Amigas native bitmap
***	  format.) 64x64 and 80x80 bitmaps are untouched, but the
***	  40x40 bitmaps got an additional 0x00 byte added to every
***	  row.
**/

#if defined(_DCC)
#define static __chip const
#elif defined(__GNUC__)
#define static const
#else
#error "Don't know how to handle your compiler."
#endif

#include "bitmaps/k80s.bm"
#include "bitmaps/q80s.bm"
#include "bitmaps/r80s.bm"
#include "bitmaps/n80s.bm"
#include "bitmaps/b80s.bm"
#include "bitmaps/p80s.bm"
#include "bitmaps/k64s.bm"
#include "bitmaps/q64s.bm"
#include "bitmaps/r64s.bm"
#include "bitmaps/n64s.bm"
#include "bitmaps/b64s.bm"
#include "bitmaps/p64s.bm"

#include "bitmaps/k44x19s.bm"
#include "bitmaps/q44x19s.bm"
#include "bitmaps/r44x19s.bm"
#include "bitmaps/n44x19s.bm"
#include "bitmaps/b44x19s.bm"
#include "bitmaps/p44x19s.bm"

#include "bitmaps/k44x22s.bm"
#include "bitmaps/q44x22s.bm"
#include "bitmaps/r44x22s.bm"
#include "bitmaps/n44x22s.bm"
#include "bitmaps/b44x22s.bm"
#include "bitmaps/p44x22s.bm"

static unsigned char k40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x44, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xba, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xba, 0x00, 0x00, 0x00,
   0x00, 0x1f, 0xba, 0xf0, 0x01, 0x00,
   0xc0, 0x60, 0xba, 0x0c, 0x06, 0x00,
   0x20, 0x9f, 0xbb, 0xf3, 0x09, 0x00,
   0xd0, 0x7f, 0xd7, 0xfd, 0x17, 0x00,
   0xe0, 0xff, 0xd6, 0xfe, 0x0f, 0x00,
   0xe8, 0xff, 0x6d, 0xff, 0x2f, 0x00,
   0xe8, 0xff, 0x29, 0xff, 0x2f, 0x00,
   0xe8, 0xff, 0xbb, 0xff, 0x2f, 0x00,
   0xc0, 0xff, 0x93, 0xff, 0x07, 0x00,
   0xd0, 0xff, 0xd7, 0xff, 0x17, 0x00,
   0xa0, 0xff, 0xd7, 0xff, 0x0b, 0x00,
   0x40, 0x7e, 0x00, 0xfc, 0x04, 0x00,
   0x80, 0x05, 0xff, 0x41, 0x03, 0x00,
   0x00, 0xf3, 0xff, 0x9f, 0x01, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0x1e, 0x00, 0xf0, 0x00, 0x00,
   0x00, 0xc6, 0xff, 0xc7, 0x00, 0x00,
   0x00, 0xfe, 0x00, 0xfe, 0x00, 0x00,
   0x00, 0x0e, 0xff, 0xe1, 0x00, 0x00,
   0x00, 0xe6, 0xff, 0xcf, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xf8, 0xff, 0x3f, 0x00, 0x00,
   0x00, 0x80, 0xff, 0x03, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


static unsigned char b40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x80, 0xff, 0x03, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xf0, 0xef, 0x1f, 0x00, 0x00,
   0x00, 0xf0, 0xef, 0x1f, 0x00, 0x00,
   0x00, 0xf8, 0xef, 0x3f, 0x00, 0x00,
   0x00, 0xf8, 0x01, 0x3f, 0x00, 0x00,
   0x00, 0xf8, 0xef, 0x3f, 0x00, 0x00,
   0x00, 0xf8, 0xef, 0x3f, 0x00, 0x00,
   0x00, 0xf8, 0xef, 0x3f, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x1f, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x1f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0x01, 0x0f, 0x00, 0x00,
   0x00, 0x40, 0x38, 0x04, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0x20, 0x00, 0x08, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x1f, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x1f, 0x00, 0x00,
   0x00, 0x80, 0xff, 0x03, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0x00, 0x00, 0x00,
   0xc0, 0xff, 0xff, 0xff, 0x07, 0x00,
   0xf0, 0xff, 0xff, 0xff, 0x1f, 0x00,
   0xf8, 0xff, 0xef, 0xff, 0x3f, 0x00,
   0xf0, 0xff, 0x83, 0xff, 0x1f, 0x00,
   0x20, 0x00, 0x00, 0x00, 0x08, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


static unsigned char n40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x08, 0x0c, 0x00, 0x00, 0x00,
   0x00, 0x38, 0x0c, 0x00, 0x00, 0x00,
   0x00, 0x78, 0x1e, 0x00, 0x00, 0x00,
   0x00, 0xf8, 0x1e, 0x00, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x03, 0x00, 0x00,
   0x00, 0x38, 0x3e, 0x0e, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0x19, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0x37, 0x00, 0x00,
   0x00, 0x9e, 0xff, 0x6f, 0x00, 0x00,
   0x00, 0xce, 0xff, 0xdf, 0x00, 0x00,
   0x00, 0xe6, 0xff, 0x9f, 0x00, 0x00,
   0x00, 0xf6, 0xff, 0x3f, 0x01, 0x00,
   0x00, 0xff, 0xff, 0x3f, 0x01, 0x00,
   0x00, 0xff, 0xff, 0x7f, 0x02, 0x00,
   0x80, 0xff, 0xff, 0x7f, 0x02, 0x00,
   0xc0, 0xff, 0xdf, 0xff, 0x06, 0x00,
   0xc0, 0xff, 0xff, 0xff, 0x04, 0x00,
   0xe0, 0xff, 0xef, 0xff, 0x04, 0x00,
   0xe0, 0xff, 0xe7, 0xff, 0x05, 0x00,
   0x30, 0xff, 0xe1, 0xff, 0x09, 0x00,
   0x30, 0x7f, 0xf0, 0xff, 0x09, 0x00,
   0xb0, 0x3f, 0xf0, 0xff, 0x09, 0x00,
   0xf0, 0x1d, 0xf8, 0xff, 0x0b, 0x00,
   0xe0, 0x0f, 0xf8, 0xff, 0x0b, 0x00,
   0xc0, 0x07, 0xfc, 0xff, 0x03, 0x00,
   0x00, 0x02, 0xfe, 0xff, 0x13, 0x00,
   0x00, 0x00, 0xff, 0xff, 0x13, 0x00,
   0x00, 0x80, 0xff, 0xff, 0x13, 0x00,
   0x00, 0x80, 0xff, 0xff, 0x13, 0x00,
   0x00, 0xc0, 0xff, 0xff, 0x13, 0x00,
   0x00, 0xc0, 0xff, 0xff, 0x13, 0x00,
   0x00, 0xe0, 0xff, 0xff, 0x13, 0x00,
   0x00, 0xe0, 0xff, 0xff, 0x17, 0x00,
   0x00, 0xe0, 0xff, 0xff, 0x1f, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


static unsigned char p40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x7c, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0x00, 0x00, 0x00,
   0x00, 0x80, 0xff, 0x03, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00,
   0x00, 0x80, 0xff, 0x03, 0x00, 0x00,
   0x00, 0x00, 0xff, 0x01, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x1f, 0x00, 0x00,
   0x00, 0xf8, 0xff, 0x3f, 0x00, 0x00,
   0x00, 0xf8, 0xff, 0x3f, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0x7f, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0x7f, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0x7f, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


static unsigned char r40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x3e, 0x7c, 0xf8, 0x00, 0x00,
   0x00, 0x3e, 0x7c, 0xf8, 0x00, 0x00,
   0x00, 0x3e, 0x7c, 0xf8, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0xf8, 0xff, 0x3f, 0x00, 0x00,
   0x00, 0xf0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0x20, 0x00, 0x08, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0xe0, 0xff, 0x0f, 0x00, 0x00,
   0x00, 0x30, 0x00, 0x18, 0x00, 0x00,
   0x00, 0xf8, 0xff, 0x7f, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0xff, 0x00, 0x00,
   0x00, 0x04, 0x00, 0xc0, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfc, 0xff, 0xff, 0x00, 0x00,
   0x80, 0x03, 0x00, 0x80, 0x03, 0x00,
   0x80, 0xff, 0xff, 0xff, 0x03, 0x00,
   0x80, 0xff, 0xff, 0xff, 0x03, 0x00,
   0x80, 0xff, 0xff, 0xff, 0x03, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


static unsigned char q40s_bits[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x38, 0x7c, 0x38, 0x00, 0x00,
   0x00, 0x7c, 0x7c, 0x7c, 0x00, 0x00,
   0x00, 0x7c, 0x7c, 0x7c, 0x00, 0x00,
   0x1c, 0x7c, 0x38, 0x7c, 0x70, 0x00,
   0x3e, 0x38, 0x10, 0x38, 0xf8, 0x00,
   0x3e, 0x10, 0x10, 0x10, 0xf8, 0x00,
   0x3e, 0x30, 0x38, 0x18, 0xf8, 0x00,
   0x1c, 0x30, 0x38, 0x18, 0x70, 0x00,
   0x30, 0x70, 0x38, 0x1c, 0x18, 0x00,
   0x30, 0x70, 0x38, 0x1c, 0x18, 0x00,
   0x70, 0x70, 0x38, 0x1c, 0x1c, 0x00,
   0xf0, 0xf8, 0x7c, 0x3e, 0x1e, 0x00,
   0xe0, 0xf8, 0x7c, 0x3e, 0x0e, 0x00,
   0xe0, 0xf9, 0x7c, 0x3e, 0x0f, 0x00,
   0xe0, 0xf9, 0x7d, 0x3f, 0x0f, 0x00,
   0xe0, 0xfb, 0x7d, 0xbf, 0x0f, 0x00,
   0xe0, 0xff, 0xff, 0xff, 0x0f, 0x00,
   0xe0, 0xff, 0xff, 0xff, 0x0f, 0x00,
   0xe0, 0xff, 0xff, 0xff, 0x07, 0x00,
   0xc0, 0xff, 0xff, 0xff, 0x07, 0x00,
   0xc0, 0xff, 0xff, 0xff, 0x07, 0x00,
   0x80, 0xff, 0xff, 0xff, 0x03, 0x00,
   0x00, 0x3f, 0x00, 0xf8, 0x01, 0x00,
   0x00, 0x83, 0xff, 0x83, 0x01, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0x3e, 0x00, 0xf8, 0x00, 0x00,
   0x00, 0xc4, 0xff, 0x47, 0x00, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x00, 0x00,
   0x00, 0xff, 0xff, 0xff, 0x01, 0x00,
   0x00, 0xfe, 0xff, 0xff, 0x01, 0x00,
   0x80, 0xff, 0xff, 0xff, 0x03, 0x00,
   0x00, 0xff, 0xff, 0xff, 0x01, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
